@@ -84,8 +84,8 @@ QAccessibleInterface *PySideAccessibleFactory::callFactories(const QString &key,
 {
     Shiboken::GilState state;
     Shiboken::AutoDecRef arglist(PyTuple_New(2));
-    PyTuple_SET_ITEM(arglist, 0, %CONVERTTOPYTHON[QString](key));
-    PyTuple_SET_ITEM(arglist, 1, %CONVERTTOPYTHON[QObject *](o));
+    PyTuple_SetItem(arglist, 0, %CONVERTTOPYTHON[QString](key));
+    PyTuple_SetItem(arglist, 1, %CONVERTTOPYTHON[QObject *](o));
 
     for (auto *f : m_factoryFunctions) {
         if (PyObject *pyResult = PyObject_CallObject(f, arglist)) {
@@ -305,14 +305,15 @@ QBitmap %0 = QBitmap::fromData(%1, buffer, %3);
 // @snippet qtextline-cursortox
 %RETURN_TYPE %0 = %CPPSELF->::%TYPE::%FUNCTION_NAME(&%1, %2);
 %PYARG_0 = PyTuple_New(2);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](%0));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[%ARG1_TYPE](%1));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](%0));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[%ARG1_TYPE](%1));
 // @snippet qtextline-cursortox
 
 // @snippet qkeysequence-getitem
-if (_i < 0 || _i >= %CPPSELF.count()) {
-    PyErr_SetString(PyExc_IndexError, "index out of bounds");
-    return 0;
+const Py_ssize_t size = %CPPSELF.count();
+if (_i < 0 || _i >= size) {
+    Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
+    return nullptr;
 }
 QKeyCombination item = (*%CPPSELF)[_i];
 return %CONVERTTOPYTHON[QKeyCombination](item);
@@ -411,8 +412,8 @@ static void imageDecrefDataHandler(void *data)
 // @snippet qimage-scanline
 
 // @snippet qcolor-setstate
-Shiboken::AutoDecRef func(PyObject_GetAttr(%PYSELF, PyTuple_GET_ITEM(%1, 0)));
-PyObject *args = PyTuple_GET_ITEM(%1, 1);
+Shiboken::AutoDecRef func(PyObject_GetAttr(%PYSELF, PyTuple_GetItem(%1, 0)));
+PyObject *args = PyTuple_GetItem(%1, 1);
 %PYARG_0 = PyObject_Call(func, args, nullptr);
 // @snippet qcolor-setstate
 
@@ -687,8 +688,8 @@ for (int r=0, r_max = %CPPSELF.rowCount(); r < r_max; r++) {
 %RETURN_TYPE retval_ = %CPPSELF.%FUNCTION_NAME(%1, %2);
 %END_ALLOW_THREADS
 %PYARG_0 = PyTuple_New(2);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](retval_));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[%ARG1_TYPE](%1));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](retval_));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[%ARG1_TYPE](%1));
 // @snippet qclipboard-text
 
 // @snippet qpainter-drawpointsnp-numpy-x-y
@@ -715,7 +716,7 @@ Shiboken::AutoDecRef seq(PySequence_Fast(%PYARG_1, "Can't turn into sequence"));
 if (PySequence_Size(seq) == 16) {
     float values[16];
     for (Py_ssize_t i = 0; i < 16; ++i) {
-        PyObject *pv = PySequence_Fast_GET_ITEM(seq.object(), i);
+        Shiboken::AutoDecRef pv(PySequence_GetItem(seq.object(), i));
         values[i] = PyFloat_AsDouble(pv);
     }
 
@@ -732,16 +733,16 @@ float values[16];
 %PYARG_0 = PyTuple_New(16);
 for (Py_ssize_t i = 0; i < 16; ++i) {
   PyObject *v = PyFloat_FromDouble(values[i]);
-  PyTuple_SET_ITEM(%PYARG_0, i, v);
+  PyTuple_SetItem(%PYARG_0, i, v);
 }
 // @snippet qmatrix4x4-copydatato
 
 // @snippet qmatrix4x4-mgetitem
 if (PySequence_Check(_key)) {
     Shiboken::AutoDecRef key(PySequence_Fast(_key, "Invalid matrix index."));
-    if (PySequence_Fast_GET_SIZE(key.object()) == 2) {
-        PyObject *posx = PySequence_Fast_GET_ITEM(key.object(), 0);
-        PyObject *posy = PySequence_Fast_GET_ITEM(key.object(), 1);
+    if (PySequence_Size(key.object()) == 2) {
+        Shiboken::AutoDecRef posx(PySequence_GetItem(key.object(), 0));
+        Shiboken::AutoDecRef posy(PySequence_GetItem(key.object(), 1));
         Py_ssize_t x = PyLong_AsSsize_t(posx);
         Py_ssize_t y = PyLong_AsSsize_t(posy);
         float ret = (*%CPPSELF)(x,y);
@@ -757,7 +758,7 @@ static void QGuiApplicationConstructor(PyObject *self, PyObject *pyargv, QGuiApp
 {
     static int argc;
     static char **argv;
-    PyObject *stringlist = PyTuple_GET_ITEM(pyargv, 0);
+    PyObject *stringlist = PyTuple_GetItem(pyargv, 0);
     if (Shiboken::listToArgcArgv(stringlist, &argc, &argv, "PySideApp")) {
         *cptr = new QGuiApplicationWrapper(argc, argv, 0);
         Shiboken::Object::releaseOwnership(reinterpret_cast<SbkObject *>(self));
@@ -894,17 +895,17 @@ QVector3D outVec{};
 float angle{};
 %CPPSELF.%FUNCTION_NAME(&outVec, &angle);
 %PYARG_0 = PyTuple_New(2);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[QVector3D](outVec));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[float](angle));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[QVector3D](outVec));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[float](angle));
 // @snippet qquaternion-getaxisandangle-vector3d-float
 
 // @snippet qquaternion-geteulerangles
 float pitch{}, yaw{}, roll{};
 %CPPSELF.%FUNCTION_NAME(&pitch, &yaw, &roll);
 %PYARG_0 = PyTuple_New(3);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[float](pitch));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[float](yaw));
-PyTuple_SET_ITEM(%PYARG_0, 2, %CONVERTTOPYTHON[float](roll));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[float](pitch));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[float](yaw));
+PyTuple_SetItem(%PYARG_0, 2, %CONVERTTOPYTHON[float](roll));
 // @snippet qquaternion-geteulerangles
 
 // @snippet qregion-len
@@ -912,8 +913,9 @@ return %CPPSELF.rectCount();
 // @snippet qregion-len
 
 // @snippet qregion-getitem
-if (_i < 0 || _i >= %CPPSELF.rectCount()) {
-    PyErr_SetString(PyExc_IndexError, "index out of bounds");
+const Py_ssize_t size = %CPPSELF.rectCount();
+if (_i < 0 || _i >= size) {
+    Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
     return nullptr;
 }
 
