@@ -148,10 +148,9 @@ static void formatPySequence(PyObject *obj, std::ostream &str)
         if (i)
             str << ", ";
         str << '(';
-        PyObject *item = PySequence_GetItem(obj, i);
+        Shiboken::AutoDecRef item(PySequence_GetItem(obj, i));
         formatPyObject(item, str);
         str << ')';
-        Py_XDECREF(item);
     }
     if (printSize < size)
         str << ",...";
@@ -482,8 +481,8 @@ bool listToArgcArgv(PyObject *argList, int *argc, char ***argv, const char *defa
 
     // Check all items
     Shiboken::AutoDecRef args(PySequence_Fast(argList, nullptr));
-    int numArgs = int(PySequence_Fast_GET_SIZE(argList));
-    for (int i = 0; i < numArgs; ++i) {
+    Py_ssize_t numArgs = PySequence_Size(argList);
+    for (Py_ssize_t i = 0; i < numArgs; ++i) {
         PyObject *item = PyList_GET_ITEM(args.object(), i);
         if (!PyBytes_Check(item) && !PyUnicode_Check(item))
             return false;
@@ -525,11 +524,11 @@ int *sequenceToIntArray(PyObject *obj, bool zeroTerminated)
     if (seq.isNull())
         return nullptr;
 
-    Py_ssize_t size = PySequence_Fast_GET_SIZE(seq.object());
+    Py_ssize_t size = PySequence_Size(seq.object());
     int *array = new int[size + (zeroTerminated ? 1 : 0)];
 
     for (int i = 0; i < size; i++) {
-        PyObject *item = PySequence_Fast_GET_ITEM(seq.object(), i);
+        Shiboken::AutoDecRef item(PySequence_GetItem(seq.object(), i));
         if (!PyLong_Check(item)) {
             PyErr_SetString(PyExc_TypeError, "Sequence of ints expected");
             delete[] array;
